@@ -45,7 +45,7 @@ sub build_terse {
 		$t->{model} = sub {
 			my ($t, $model) = @_;
 			$t->raiseError("invalid model: ${model}", 400) unless $self->models->$model;
-			return $t->models->$model ||= $self->models->$model->connect();
+			return $t->models->$model ||= $self->models->$model->connect($t);
 		};
 	}
 	if ($self->controllers) {
@@ -77,7 +77,7 @@ sub build_terse {
 			my ($t, $plugin) = @_;
 			$t->raiseError("invalid plugin: ${plugin}", 400) unless $self->plugins->{$plugin};
 			return $t->plugins->$plugin ||= ($self->plugins->{$plugin}->can('connect') 
-				? $self->plugins->{$plugin}->connect() 
+				? $self->plugins->{$plugin}->connect($t) 
 				: $self->plugins->{$plugin});
 		};
 	}
@@ -240,7 +240,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.109
+Version 0.110
 
 =cut
 
