@@ -31,7 +31,7 @@ sub hello :any(hello_world) :path(hello/world) {
 	$_[1]->response->hello = "world";
 }
 
-sub hello_get :get :path(hello/get) {
+sub hello_get :get :path(hello/(.*)/get) :captured(1) {
 	$_[1]->response->hello = $_[1]->model('test')->something;
 }
 
